StateMachine

Enum StateMachine 

pub enum StateMachine {
Show 174 variants SpaceA, SpaceB, SpaceC, SpaceD, SpaceF, SpaceH, SpaceI, SpaceK, SpaceL, SpaceM, SpaceN, SpaceS, SpaceT, SpaceW, SpaceY, ExclamationSpace, ExclamationExclamation, CommaComma, CommaA, CommaB, CommaC, CommaH, CommaI, CommaL, CommaN, CommaS, CommaT, CommaW, CommaY, PeriodSpace, PeriodPeriod, Ad, Al, Am, An, Ap, At, Aw, Ay, BExclamation, BComma, BPeriod, Bl, Bo, Ca, Cr, Cu, DSpace, Db, Dd, Dl, Do, ESpace, EExclamation, EComma, EPeriod, Em, En, Eo, Es, FSpace, Fl, Ge, Gl, Ha, He, Hr, IExclamation, IComma, IPeriod, Ic, Id, Ie, Ik, Im, In, Ip, It, Iv, Kd, Ke, Ki, Kl, Ko, Ku, Ky, LSpace, Le, Li, Lo, Lu, Ly, MSpace, Mb, Me, Mi, Mo, Mt, NSpace, NExclamation, NComma, NPeriod, Na, Nd, Nf, Ng, Nk, No, Np, OSpace, OExclamation, OComma, OPeriod, Oi, Ok, Ol, On, Oo, Or, Ot, Ou, Ow, PSpace, Pp, Pr, Ps, Pu, Py, Ri, Rn, Ro, Ru, SExclamation, SComma, SPeriod, Sc, Sh, Si, Sm, So, Sp, St, Sy, TSpace, TExclamation, TComma, TPeriod, Ta, Te, Th, Ti, Tl, To, Ts, Tt, Ty, Ub, Un, Us, Ut, Ve, WSpace, WExclamation, WComma, WPeriod, Wh, Wi, Wm, Ww, YSpace, YExclamation, YComma, YPeriod, Ya,
}

Variants



SpaceA



SpaceB



SpaceC



SpaceD



SpaceF



SpaceH



SpaceI



SpaceK



SpaceL



SpaceM



SpaceN



SpaceS



SpaceT



SpaceW



SpaceY



ExclamationSpace



ExclamationExclamation



CommaComma



CommaA



CommaB



CommaC



CommaH



CommaI



CommaL



CommaN



CommaS



CommaT



CommaW



CommaY



PeriodSpace



PeriodPeriod



Ad



Al



Am



An



Ap



At



Aw



Ay



BExclamation



BComma



BPeriod



Bl



Bo



Ca



Cr



Cu



DSpace



Db



Dd



Dl



Do



ESpace



EExclamation



EComma



EPeriod



Em



En



Eo



Es



FSpace



Fl



Ge



Gl



Ha



He



Hr



IExclamation



IComma



IPeriod



Ic



Id



Ie



Ik



Im



In



Ip



It



Iv



Kd



Ke



Ki



Kl



Ko



Ku



Ky



LSpace



Le



Li



Lo



Lu



Ly



MSpace



Mb



Me



Mi



Mo



Mt



NSpace



NExclamation



NComma



NPeriod



Na



Nd



Nf



Ng



Nk



No



Np



OSpace



OExclamation



OComma



OPeriod



Oi



Ok



Ol



On



Oo



Or



Ot



Ou



Ow



PSpace



Pp



Pr



Ps



Pu



Py



Ri



Rn



Ro



Ru



SExclamation



SComma



SPeriod



Sc



Sh



Si



Sm



So



Sp



St



Sy



TSpace



TExclamation



TComma



TPeriod



Ta



Te



Th



Ti



Tl



To



Ts



Tt



Ty



Ub



Un



Us



Ut



Ve



WSpace



WExclamation



WComma



WPeriod



Wh



Wi



Wm



Ww



YSpace



YExclamation



YComma



YPeriod



Ya

Implementations

Source

impl StateMachine

pub fn generate(self, rng: impl RngCore) -> (Self, char)

pub fn new_random(rng: impl RngCore) -> (Self, &'static str)